@@ -1,24 +1,11 @@
 /*
   This file is part of the KDE Kontact Plugin Interface Library.
 
-  Copyright (c) 2001 Matthias Hoelzer-Kluepfel <mhk@kde.org>
-  Copyright (c) 2002-2003 Daniel Molkentin <molkentin@kde.org>
-  Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2001 Matthias Hoelzer-Kluepfel <mhk@kde.org>
+  SPDX-FileCopyrightText: 2002-2003 Daniel Molkentin <molkentin@kde.org>
+  SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "core.h"
@@ -47,7 +34,7 @@ public:
 
     QString lastErrorMessage;
     QDate mLastDate;
-    QMap<QByteArray, KParts::ReadOnlyPart *> mParts;
+    QMap<QByteArray, KParts::Part *> mParts;
 };
 
 Core::Private::Private(Core *qq)
@@ -69,11 +56,11 @@ Core::~Core()
     delete d;
 }
 
-KParts::ReadOnlyPart *Core::createPart(const char *libname)
+KParts::Part *Core::createPart(const char *libname)
 {
     qCDebug(KONTACTINTERFACE_LOG) << libname;
 
-    QMap<QByteArray, KParts::ReadOnlyPart *>::ConstIterator it;
+    QMap<QByteArray, KParts::Part *>::ConstIterator it;
     it = d->mParts.constFind(libname);
     if (it != d->mParts.constEnd()) {
         return it.value();
@@ -84,14 +71,14 @@ KParts::ReadOnlyPart *Core::createPart(const char *libname)
     KPluginLoader loader(QString::fromLatin1(libname));
     qCDebug(KONTACTINTERFACE_LOG) << loader.fileName();
     KPluginFactory *factory = loader.factory();
-    KParts::ReadOnlyPart *part = nullptr;
+    KParts::Part *part = nullptr;
     if (factory) {
-        part = factory->create<KParts::ReadOnlyPart>(this);
+        part = factory->create<KParts::Part>(this);
     }
 
     if (part) {
         d->mParts.insert(libname, part);
-        QObject::connect(part, &KParts::ReadOnlyPart::destroyed,
+        QObject::connect(part, &KParts::Part::destroyed,
                          this, [this](QObject* obj) { d->slotPartDestroyed(obj);});
     } else {
         d->lastErrorMessage = loader.errorString();
@@ -106,8 +93,8 @@ void Core::Private::slotPartDestroyed(QObject *obj)
 {
     // the part was deleted, we need to remove it from the part map to not return
     // a dangling pointer in createPart
-    const QMap<QByteArray, KParts::ReadOnlyPart *>::Iterator end = mParts.end();
-    QMap<QByteArray, KParts::ReadOnlyPart *>::Iterator it = mParts.begin();
+    const QMap<QByteArray, KParts::Part *>::Iterator end = mParts.end();
+    QMap<QByteArray, KParts::Part *>::Iterator it = mParts.begin();
     for (; it != end; ++it) {
         if (it.value() == obj) {
             mParts.erase(it);
@@ -119,7 +106,7 @@ void Core::Private::slotPartDestroyed(QObject *obj)
 void Core::Private::checkNewDay()
 {
     if (mLastDate != QDate::currentDate()) {
-        emit q->dayChanged(QDate::currentDate());
+        Q_EMIT q->dayChanged(QDate::currentDate());
     }
 
     mLastDate = QDate::currentDate();
